# -*- coding: utf-8 -*-


"""folstamp scripts package

External scripts used in the performance of the program.
"""

__author__ = 'Borja González Seoane'
__copyright__ = 'Copyright 2019, Borja González Seoane'
__credits__ = 'Borja González Seoane, retif (https://github.com/retifrav)'
__license__ = 'LICENSE'
__version__ = '1.1'
__maintainer__ = 'Borja González Seoane'
__email__ = 'dev@glezseoane.com'
__status__ = 'Development'
